@@ -1,8 +1,9 @@
-/* Copyright 2000-2004 The Apache Software Foundation
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/* Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -66,36 +67,9 @@ extern "C" {
 /** signal numbers typedef */
 typedef int               apr_signum_t;
 
-/**
- * Finding offsets of elements within structures.
- * Taken from the X code... they've sweated portability of this stuff
- * so we don't have to.  Sigh...
- * @param p_type pointer type name
- * @param field  data field within the structure pointed to
- * @return offset
- */
-
-#if defined(CRAY) || (defined(__arm) && !defined(LINUX))
-#ifdef __STDC__
-#define APR_OFFSET(p_type,field) _Offsetof(p_type,field)
-#else
-#ifdef CRAY2
-#define APR_OFFSET(p_type,field) \
-        (sizeof(int)*((unsigned int)&(((p_type)NULL)->field)))
-
-#else /* !CRAY2 */
-
-#define APR_OFFSET(p_type,field) ((unsigned int)&(((p_type)NULL)->field))
-
-#endif /* !CRAY2 */
-#endif /* __STDC__ */
-#else /* ! (CRAY || __arm) */
-
 #define APR_OFFSET(p_type,field) \
         ((long) (((char *) (&(((p_type)NULL)->field))) - ((char *) NULL)))
 
-#endif /* !CRAY */
-
 /**
  * Finding offsets of elements within structures.
  * @param s_type structure type name
@@ -143,10 +117,13 @@ int strncasecmp(const char *a, const char *b, size_t n);
  * String and memory functions
  */
 
+/* APR_STRINGIFY is defined here, and also in apr_release.h, so wrap it */
+#ifndef APR_STRINGIFY
 /** Properly quote a value as a string in the C preprocessor */
 #define APR_STRINGIFY(n) APR_STRINGIFY_HELPER(n)
 /** Helper macro for APR_STRINGIFY */
 #define APR_STRINGIFY_HELPER(n) #n
+#endif
 
 #if (!APR_HAVE_MEMMOVE)
 #define memmove(a,b,c) bcopy(b,a,c)
@@ -165,7 +142,8 @@ void *memchr(const void *s, int c, size_t n);
 
 /**
  * Setup any APR internal data structures.  This MUST be the first function 
- * called for any APR library.
+ * called for any APR library. It is safe to call apr_initialize several
+ * times as long as apr_terminate is called the same number of times.
  * @remark See apr_app_initialize if this is an application, rather than
  * a library consumer of apr.
  */
@@ -189,7 +167,8 @@ APR_DECLARE(apr_status_t) apr_app_initialize(int *argc,
 
 /**
  * Tear down any APR internal data structures which aren't torn down 
- * automatically.
+ * automatically. apr_terminate must be called once for every call to
+ * apr_initialize() or apr_app_initialize().
  * @remark An APR program must call this function at termination once it 
  *         has stopped using APR services.  The APR developers suggest using
  *         atexit to ensure this is called.  When using APR from a language
